Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(81)

Unified Diff: ios/chrome/browser/ui/content_suggestions/content_suggestions_commands.h

Issue 2644123003: Move ios/ui/suggestions to ios/ui/content_suggestions (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_commands.h
diff --git a/ios/chrome/browser/ui/suggestions/suggestions_commands.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_commands.h
similarity index 57%
rename from ios/chrome/browser/ui/suggestions/suggestions_commands.h
rename to ios/chrome/browser/ui/content_suggestions/content_suggestions_commands.h
index 501b4972fbe1e39a988574fda81e172612e817a9..7a229627d9417821243028becf26d9000bf3a0fa 100644
--- a/ios/chrome/browser/ui/suggestions/suggestions_commands.h
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_commands.h
@@ -2,11 +2,11 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_COMMANDS_H_
-#define IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_COMMANDS_H_
+#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_COMMANDS_H_
+#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_COMMANDS_H_
-// Commands protocol for the SuggestionsViewController.
-@protocol SuggestionsCommands
+// Commands protocol for the ContentSuggestionsViewController.
+@protocol ContentSuggestionsCommands
// Adds a new empty SuggestionItem.
- (void)addEmptyItem;
@@ -19,4 +19,4 @@
@end
-#endif // IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_COMMANDS_H_
+#endif // IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_COMMANDS_H_

Powered by Google App Engine
This is Rietveld 408576698